==> haskell-what4-1.5.1-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-what4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 what4
version:              1.5.1
visibility:           public
id:                   what4-1.5.1-5TilHRclsGL99gZI4YnI8V
key:                  what4-1.5.1-5TilHRclsGL99gZI4YnI8V
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  1b4f5117162d7accff01ee50a1d663ca
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Boolector What4.Solver.CVC4 What4.Solver.CVC5
    What4.Solver.DReal What4.Solver.ExternalABC What4.Solver.STP
    What4.Solver.Yices What4.Solver.Z3 What4.SpecialFunctions
    What4.Symbol What4.Utils.AbstractDomains What4.Utils.AnnotatedMap
    What4.Utils.Arithmetic What4.Utils.BVDomain
    What4.Utils.BVDomain.Arith What4.Utils.BVDomain.Bitwise
    What4.Utils.BVDomain.XOR What4.Utils.Complex What4.Utils.Endian
    What4.Utils.Environment What4.Utils.FloatHelpers
    What4.Utils.HandleReader What4.Utils.IncrHash What4.Utils.LeqMap
    What4.Utils.MonadST What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.2.8/site-local/what4-1.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/what4-1.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.5.1-5TilHRclsGL99gZI4YnI8V
depends:
    BoundedChan-1.0.3.0-GASw0jI0hsI8wIs0B8SAkA
    async-2.2.5-cqcrAyJc5KBpUy7cUuVT7
    attoparsec-0.14.4-HI028cZ2WwJ53VFJd3R6KF base-4.16.4.0
    bifunctors-5.6-2KI6ByfEIUPCXicVA1OACE
    bimap-0.5.0-APmfb0xtxqn92HSKOZovlc
    bv-sized-1.0.5-9kALtim9F2oL6vRQ9HtNtN bytestring-0.11.4.0
    concurrent-extra-0.7.0.12-jAkn8sqlvz2KWnADAWAop
    config-value-0.8.3-8yCRuGm4wH18pEPQuVa8HA containers-0.6.5.1
    deepseq-1.4.6.1 deriving-compat-0.6.6-9GbCtj8GRkQJHx5DRJFPaF
    directory-1.3.6.2 exceptions-0.10.4 filepath-1.4.2.2
    fingertree-0.1.5.0-FElNsZpmvC3Eok5oGczSRT ghc-prim-0.8.0
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    hashtables-1.3.1-wnosz65fsL1zLRXv1XqyS
    io-streams-1.5.2.2-GOctHVyl5zA2PM884JGDoB
    lens-5.2.3-Ay8F9EUtjnE9PU0we5yejR
    libBF-0.6.6-BitWnB3w72HEADGrPceN3f
    megaparsec-9.6.1-1rJqRfK4Cgi6LJwevmLrVi mtl-2.2.2
    ordered-containers-0.2.4-VS2l5MKwUI7EEwfaqIhmz
    panic-0.4.0.1-HPbW5wuhX2x4TYrkc6yjYz
    parameterized-utils-2.1.9.0-KBXH4wAErvF6dDOOjduqzK parsec-3.1.15.0
    prettyprinter-1.7.1-AHlSRvD5inVfGUmGNNjcf process-1.6.16.0
    s-cargot-0.1.6.0-GgcaYaNdSHf6sfanulso8V
    scientific-0.3.7.0-KltKYIXlMCy1e9qM9TkhQF stm-2.5.0.2
    template-haskell-2.18.0.0 temporary-1.3-DlPEuuewvsKrIwgXPFoMU
    text-1.2.5.0 th-lift-0.8.4-7yLYwH7OaPD4aJs3FpHkYY
    th-lift-instances-0.1.20-B3yLbD64hLM5yAz5cTOL68 time-1.11.1.1
    transformers-0.5.6.2 unliftio-0.2.25.1-8L6BiCnh80y1RfJtEqTngb
    unordered-containers-0.2.20-DtI6Ump4gwL4XOoZ2vYwmp
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP
    versions-6.0.4-DHJ41aNKqUOCvhQpxfVDl
    zenc-0.1.2-5ckiL7MSTikBiBMswvbXMS

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-what4-1.5.1-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-what4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 what4
version:              1.5.1
visibility:           public
id:                   what4-1.5.1-BDylFluohwX2jgzfp7Zp4J
key:                  what4-1.5.1-BDylFluohwX2jgzfp7Zp4J
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  b45a937efa0d93408acd32d69c20e08a
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Boolector What4.Solver.CVC4 What4.Solver.CVC5
    What4.Solver.DReal What4.Solver.ExternalABC What4.Solver.STP
    What4.Solver.Yices What4.Solver.Z3 What4.SpecialFunctions
    What4.Symbol What4.Utils.AbstractDomains What4.Utils.AnnotatedMap
    What4.Utils.Arithmetic What4.Utils.BVDomain
    What4.Utils.BVDomain.Arith What4.Utils.BVDomain.Bitwise
    What4.Utils.BVDomain.XOR What4.Utils.Complex What4.Utils.Endian
    What4.Utils.Environment What4.Utils.FloatHelpers
    What4.Utils.HandleReader What4.Utils.IncrHash What4.Utils.LeqMap
    What4.Utils.MonadST What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.2.8/site-local/what4-1.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/what4-1.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.5.1-BDylFluohwX2jgzfp7Zp4J
depends:
    BoundedChan-1.0.3.0-GASw0jI0hsI8wIs0B8SAkA
    async-2.2.5-BuJk1pCvRYOCTk3w3YOF9n
    attoparsec-0.14.4-5wZOVAk6w2AKDrkEEe6wrE base-4.16.4.0
    bifunctors-5.6-5baFR4G1NNA2dTSLODLqvQ
    bimap-0.5.0-JmiXlOC1aH61Ofma2zmUzy
    bv-sized-1.0.5-IlR5AFG1x1m7tXH2ZYhd6Z bytestring-0.11.4.0
    concurrent-extra-0.7.0.12-KEirmnQf8P9COomnZX94nr
    config-value-0.8.3-8yCRuGm4wH18pEPQuVa8HA containers-0.6.5.1
    deepseq-1.4.6.1 deriving-compat-0.6.6-BjMNSfTzdC0DPPcG8VwMLZ
    directory-1.3.6.2 exceptions-0.10.4 filepath-1.4.2.2
    fingertree-0.1.5.0-5LF4k5tmEsjCAcmmOCL9WT ghc-prim-0.8.0
    hashable-1.4.4.0-EsPTAmPpYqX3hovcHlHOLX
    hashtables-1.3.1-DzDaSX3nGjO1Cu3QfXIUcF
    io-streams-1.5.2.2-27mevNN08NvBjfoThwSYvA
    lens-5.2.3-ArLZ6zglf4zFaksKXWD2Ie
    libBF-0.6.6-JhVEjzJcxDLHzYgecaDA0k
    megaparsec-9.6.1-Dn81ShDhbeo4gs6wUVAEFU mtl-2.2.2
    ordered-containers-0.2.4-4IbzNBhybg68H6tII6CnH4
    panic-0.4.0.1-HPbW5wuhX2x4TYrkc6yjYz
    parameterized-utils-2.1.9.0-5E0WpjY8OOMCgq4GVzwHi6 parsec-3.1.15.0
    prettyprinter-1.7.1-AXGwST4URaJEx6H9Czu9UT process-1.6.16.0
    s-cargot-0.1.6.0-CgJFkshNojvJSvY8vZmPmS
    scientific-0.3.7.0-1j3FKEOO1AWBjqM65TX7Sj stm-2.5.0.2
    template-haskell-2.18.0.0 temporary-1.3-GZoJLsDPRdF24FKBwWSH1J
    text-1.2.5.0 th-lift-0.8.4-7yLYwH7OaPD4aJs3FpHkYY
    th-lift-instances-0.1.20-B3Kq1iep7z07arJmqpH6j5 time-1.11.1.1
    transformers-0.5.6.2 unliftio-0.2.25.1-CkFJ8hPpvZqDy07m1hxo9U
    unordered-containers-0.2.20-3olzmtJszxXc2LJr1lW5F
    utf8-string-1.0.2-AaPuiI83MyhDGzjGdO2RZO
    vector-0.13.1.0-IOwb1qSGKSdHIyg7Qp7MNu
    versions-6.0.4-4MQ5nD1Whm3LXa7eQdcGV
    zenc-0.1.2-KT5CZjsectVKcIyViUMCM4

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
